@@ -1,3 +1,3 @@
 """The mapdl database module, allowing the access to the MAPDL database from Python."""
 
-from .database import DBDef, MapdlDb  # noqa: F401
+from .database import DBDef, MapdlDb, check_mapdl_db_is_alive  # noqa: F401
