@@ -22,7 +22,7 @@ import appdirs
 
 from ansys.mapdl import core as pymapdl
 from ansys.mapdl.core import LOG
-from ansys.mapdl.core.errors import LockFileException, VersionError
+from ansys.mapdl.core.errors import LockFileException, MapdlDidNotStart, VersionError
 from ansys.mapdl.core.licensing import ALLOWABLE_LICENSES, LicenseChecker
 from ansys.mapdl.core.mapdl import _MapdlCore
 from ansys.mapdl.core.mapdl_grpc import MAX_MESSAGE_LENGTH, MapdlGrpc
@@ -220,8 +220,10 @@ def launch_grpc(
     override=True,
     timeout=20,
     verbose=False,
+    add_env_vars=None,
+    replace_env_vars=None,
     **kwargs,
-) -> tuple:
+) -> tuple:  # pragma: no cover
     """Start MAPDL locally in gRPC mode.
 
     Parameters
@@ -497,9 +499,13 @@ def launch_grpc(
         )
         command = " ".join(command_parm)
 
-    if verbose:
-        print(f"Running {command}")
-        subprocess.Popen(command, shell=os.name != "nt", cwd=run_location)
+    env_vars = update_env_vars(add_env_vars, replace_env_vars)
+
+    LOG.info(f"Running in {ip}:{port} the following command: '{command}'")
+
+    if verbose:  # pragma: no cover
+        subprocess.Popen(command, shell=os.name != "nt", cwd=run_location, env=env_vars)
+
     else:
         subprocess.Popen(
             command,
@@ -508,6 +514,7 @@ def launch_grpc(
             stdin=subprocess.DEVNULL,
             stdout=subprocess.DEVNULL,
             stderr=subprocess.DEVNULL,
+            env=env_vars,
         )
 
     # watch for the creation of temporary files at the run_directory.
@@ -520,9 +527,15 @@ def launch_grpc(
         files = os.listdir(run_location)
         has_ans = any([filename for filename in files if ".err" in filename])
         if has_ans:
+            LOG.info("MAPDL session successfully started (Error file found)")
             break
         time.sleep(sleep_time)
 
+    if not has_ans:
+        raise MapdlDidNotStart(
+            f"MAPDL failed to start (No err file generated in '{run_location}')"
+        )
+
     return port, run_location
 
 
@@ -973,6 +986,8 @@ def launch_mapdl(
     license_server_check=True,
     license_type=None,
     print_com=False,
+    add_env_vars=None,
+    replace_env_vars=None,
     **kwargs,
 ) -> _MapdlCore:
     """Start MAPDL locally.
@@ -1068,9 +1083,9 @@ def launch_mapdl(
         environment variable "PYMAPDL_IP=FALSE".
 
     clear_on_connect : bool, optional
-        Used only when ``start_instance`` is ``False``.  Defaults to
-        ``True``, giving you a fresh environment when connecting to
-        MAPDL.
+        Defaults to ``True``, giving you a fresh environment when
+        connecting to MAPDL. When if ``start_instance`` is specified
+        it defaults to ``False``.
 
     log_apdl : str, optional
         Enables logging every APDL command to the local disk.  This
@@ -1104,6 +1119,16 @@ def launch_mapdl(
         Print the command ``/COM`` arguments to the standard output.
         Default ``False``.
 
+    add_env_vars : dict, optional
+        The provided dictionary will be used to extend the system or process
+        environment variables. If you want to control all of the environment
+        variables, use ``replace_env_vars``. Defaults to ``None``.
+
+    replace_env_vars : dict, optional
+        The provided dictionary will be used to replace all the system or process
+        environment variables. To just add some environment variables to the MAPDL
+        process, use ``add_env_vars``. Defaults to ``None``.
+
     Returns
     -------
     ansys.mapdl.core.mapdl._MapdlCore
@@ -1313,7 +1338,10 @@ def launch_mapdl(
             return mapdl
 
     if not start_instance:
-        return MapdlGrpc(
+        if clear_on_connect is None:  # pragma: no cover
+            clear_on_connect = False
+
+        mapdl = MapdlGrpc(
             ip=ip,
             port=port,
             cleanup_on_exit=False,
@@ -1475,7 +1503,12 @@ def launch_mapdl(
             )
         elif mode == "grpc":
             port, actual_run_location = launch_grpc(
-                port=port, verbose=verbose_mapdl, ip=ip, **start_parm
+                port=port,
+                verbose=verbose_mapdl,
+                ip=ip,
+                add_env_vars=add_env_vars,
+                replace_env_vars=replace_env_vars,
+                **start_parm,
             )
             mapdl = MapdlGrpc(
                 ip=ip,
@@ -1559,3 +1592,48 @@ def check_mode(mode, version):
         warnings.warn("MAPDL as a service has not been tested on MAPDL < v13")
 
     return mode
+
+
+def update_env_vars(add_env_vars, replace_env_vars):
+    """
+    Update environment variables for the MAPDL process.
+
+    Parameters
+    ----------
+    add_env_vars : dict, None
+        Dictionary with a mapping of env variables.
+    replace_env_vars : dict, None
+        Dictionary with a mapping of env variables.
+
+    Raises
+    ------
+    TypeError
+        'add_env_vars' and 'replace_env_vars' are incompatible. Please provide only one.
+    TypeError
+        The variable 'add_env_vars' should be a dict with env vars.
+    TypeError
+        The variable 'replace_env_vars' should be a dict with env vars.
+    """
+
+    # Expanding/replacing env variables for the process.
+    if add_env_vars and replace_env_vars:
+        raise ValueError(
+            "'add_env_vars' and 'replace_env_vars' are incompatible. Please provide only one."
+        )
+
+    elif add_env_vars:
+        if not isinstance(add_env_vars, dict):
+            raise TypeError(
+                "The variable 'add_env_vars' should be a dict with env vars."
+            )
+
+        add_env_vars.update(os.environ)
+        return add_env_vars
+
+    elif replace_env_vars:
+        if not isinstance(replace_env_vars, dict):
+            raise TypeError(
+                "The variable 'replace_env_vars' should be a dict with env vars."
+            )
+
+        return replace_env_vars
